@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -23,10 +23,13 @@ from tencentcloud.tiems.v20190416 import models
 class TiemsClient(AbstractClient):
     _apiVersion = '2019-04-16'
     _endpoint = 'tiems.tencentcloudapi.com'
+    _service = 'tiems'
 
 
     def CreateJob(self, request):
-        """创建任务
+        """因业务策略调整，腾讯云TI平台TI-EMS已经于2022年6月30日下线并停止提供服务。若您有新增的业务需求，可前往TI-ONE(https://cloud.tencent.com/document/product/851)使用。
+
+        创建任务
 
         :param request: Request instance for CreateJob.
         :type request: :class:`tencentcloud.tiems.v20190416.models.CreateJobRequest`
@@ -35,7 +38,8 @@ class TiemsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateJob", params)
+            headers = request.headers
+            body = self.call("CreateJob", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateJobResponse()
@@ -54,7 +58,9 @@ class TiemsClient(AbstractClient):
 
 
     def CreateRsgAsGroup(self, request):
-        """创建资源组的伸缩组。当前一个资源组仅允许创建一个伸缩组。
+        """因业务策略调整，腾讯云TI平台TI-EMS已经于2022年6月30日下线并停止提供服务。若您有新增的业务需求，可前往TI-ONE(https://cloud.tencent.com/document/product/851)使用。
+
+        创建资源组的伸缩组。当前一个资源组仅允许创建一个伸缩组。
 
         :param request: Request instance for CreateRsgAsGroup.
         :type request: :class:`tencentcloud.tiems.v20190416.models.CreateRsgAsGroupRequest`
@@ -63,7 +69,8 @@ class TiemsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateRsgAsGroup", params)
+            headers = request.headers
+            body = self.call("CreateRsgAsGroup", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateRsgAsGroupResponse()
@@ -82,7 +89,9 @@ class TiemsClient(AbstractClient):
 
 
     def CreateRuntime(self, request):
-        """创建运行环境
+        """因业务策略调整，腾讯云TI平台TI-EMS已经于2022年6月30日下线并停止提供服务。若您有新增的业务需求，可前往TI-ONE(https://cloud.tencent.com/document/product/851)使用。
+
+        创建运行环境
 
         :param request: Request instance for CreateRuntime.
         :type request: :class:`tencentcloud.tiems.v20190416.models.CreateRuntimeRequest`
@@ -91,7 +100,8 @@ class TiemsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateRuntime", params)
+            headers = request.headers
+            body = self.call("CreateRuntime", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateRuntimeResponse()
@@ -110,7 +120,9 @@ class TiemsClient(AbstractClient):
 
 
     def CreateService(self, request):
-        """创建服务
+        """因业务策略调整，腾讯云TI平台TI-EMS已经于2022年6月30日下线并停止提供服务。若您有新增的业务需求，可前往TI-ONE(https://cloud.tencent.com/document/product/851)使用。
+
+        创建服务
 
         :param request: Request instance for CreateService.
         :type request: :class:`tencentcloud.tiems.v20190416.models.CreateServiceRequest`
@@ -119,7 +131,8 @@ class TiemsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateService", params)
+            headers = request.headers
+            body = self.call("CreateService", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateServiceResponse()
@@ -138,7 +151,9 @@ class TiemsClient(AbstractClient):
 
 
     def CreateServiceConfig(self, request):
-        """创建服务配置
+        """因业务策略调整，腾讯云TI平台TI-EMS已经于2022年6月30日下线并停止提供服务。若您有新增的业务需求，可前往TI-ONE(https://cloud.tencent.com/document/product/851)使用。
+
+        创建服务配置
 
         :param request: Request instance for CreateServiceConfig.
         :type request: :class:`tencentcloud.tiems.v20190416.models.CreateServiceConfigRequest`
@@ -147,7 +162,8 @@ class TiemsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateServiceConfig", params)
+            headers = request.headers
+            body = self.call("CreateServiceConfig", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateServiceConfigResponse()
@@ -166,7 +182,9 @@ class TiemsClient(AbstractClient):
 
 
     def DeleteInstance(self, request):
-        """删除资源组中的节点。目前仅支持删除已经到期的预付费节点，和按量付费节点。
+        """因业务策略调整，腾讯云TI平台TI-EMS已经于2022年6月30日下线并停止提供服务。若您有新增的业务需求，可前往TI-ONE(https://cloud.tencent.com/document/product/851)使用。
+
+        删除资源组中的节点。目前仅支持删除已经到期的预付费节点，和按量付费节点。
 
         :param request: Request instance for DeleteInstance.
         :type request: :class:`tencentcloud.tiems.v20190416.models.DeleteInstanceRequest`
@@ -175,7 +193,8 @@ class TiemsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteInstance", params)
+            headers = request.headers
+            body = self.call("DeleteInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteInstanceResponse()
@@ -194,7 +213,9 @@ class TiemsClient(AbstractClient):
 
 
     def DeleteJob(self, request):
-        """删除任务
+        """因业务策略调整，腾讯云TI平台TI-EMS已经于2022年6月30日下线并停止提供服务。若您有新增的业务需求，可前往TI-ONE(https://cloud.tencent.com/document/product/851)使用。
+
+        删除任务
 
         :param request: Request instance for DeleteJob.
         :type request: :class:`tencentcloud.tiems.v20190416.models.DeleteJobRequest`
@@ -203,7 +224,8 @@ class TiemsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteJob", params)
+            headers = request.headers
+            body = self.call("DeleteJob", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteJobResponse()
@@ -222,7 +244,9 @@ class TiemsClient(AbstractClient):
 
 
     def DeleteResourceGroup(self, request):
-        """删除资源组
+        """因业务策略调整，腾讯云TI平台TI-EMS已经于2022年6月30日下线并停止提供服务。若您有新增的业务需求，可前往TI-ONE(https://cloud.tencent.com/document/product/851)使用。
+
+        删除资源组
 
         :param request: Request instance for DeleteResourceGroup.
         :type request: :class:`tencentcloud.tiems.v20190416.models.DeleteResourceGroupRequest`
@@ -231,7 +255,8 @@ class TiemsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteResourceGroup", params)
+            headers = request.headers
+            body = self.call("DeleteResourceGroup", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteResourceGroupResponse()
@@ -250,7 +275,9 @@ class TiemsClient(AbstractClient):
 
 
     def DeleteRsgAsGroup(self, request):
-        """伸缩
+        """因业务策略调整，腾讯云TI平台TI-EMS已经于2022年6月30日下线并停止提供服务。若您有新增的业务需求，可前往TI-ONE(https://cloud.tencent.com/document/product/851)使用。
+
+        伸缩
 
         :param request: Request instance for DeleteRsgAsGroup.
         :type request: :class:`tencentcloud.tiems.v20190416.models.DeleteRsgAsGroupRequest`
@@ -259,7 +286,8 @@ class TiemsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteRsgAsGroup", params)
+            headers = request.headers
+            body = self.call("DeleteRsgAsGroup", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteRsgAsGroupResponse()
@@ -278,7 +306,9 @@ class TiemsClient(AbstractClient):
 
 
     def DeleteRuntime(self, request):
-        """删除运行环境
+        """因业务策略调整，腾讯云TI平台TI-EMS已经于2022年6月30日下线并停止提供服务。若您有新增的业务需求，可前往TI-ONE(https://cloud.tencent.com/document/product/851)使用。
+
+        删除运行环境
 
         :param request: Request instance for DeleteRuntime.
         :type request: :class:`tencentcloud.tiems.v20190416.models.DeleteRuntimeRequest`
@@ -287,7 +317,8 @@ class TiemsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteRuntime", params)
+            headers = request.headers
+            body = self.call("DeleteRuntime", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteRuntimeResponse()
@@ -306,7 +337,9 @@ class TiemsClient(AbstractClient):
 
 
     def DeleteService(self, request):
-        """删除服务
+        """因业务策略调整，腾讯云TI平台TI-EMS已经于2022年6月30日下线并停止提供服务。若您有新增的业务需求，可前往TI-ONE(https://cloud.tencent.com/document/product/851)使用。
+
+        删除服务
 
         :param request: Request instance for DeleteService.
         :type request: :class:`tencentcloud.tiems.v20190416.models.DeleteServiceRequest`
@@ -315,7 +348,8 @@ class TiemsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteService", params)
+            headers = request.headers
+            body = self.call("DeleteService", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteServiceResponse()
@@ -334,7 +368,9 @@ class TiemsClient(AbstractClient):
 
 
     def DeleteServiceConfig(self, request):
-        """删除服务配置
+        """因业务策略调整，腾讯云TI平台TI-EMS已经于2022年6月30日下线并停止提供服务。若您有新增的业务需求，可前往TI-ONE(https://cloud.tencent.com/document/product/851)使用。
+
+        删除服务配置
 
         :param request: Request instance for DeleteServiceConfig.
         :type request: :class:`tencentcloud.tiems.v20190416.models.DeleteServiceConfigRequest`
@@ -343,7 +379,8 @@ class TiemsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteServiceConfig", params)
+            headers = request.headers
+            body = self.call("DeleteServiceConfig", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteServiceConfigResponse()
@@ -362,7 +399,9 @@ class TiemsClient(AbstractClient):
 
 
     def DescribeInstances(self, request):
-        """获取节点列表
+        """因业务策略调整，腾讯云TI平台TI-EMS已经于2022年6月30日下线并停止提供服务。若您有新增的业务需求，可前往TI-ONE(https://cloud.tencent.com/document/product/851)使用。
+
+        获取节点列表
 
         :param request: Request instance for DescribeInstances.
         :type request: :class:`tencentcloud.tiems.v20190416.models.DescribeInstancesRequest`
@@ -371,7 +410,8 @@ class TiemsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeInstances", params)
+            headers = request.headers
+            body = self.call("DescribeInstances", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeInstancesResponse()
@@ -390,7 +430,9 @@ class TiemsClient(AbstractClient):
 
 
     def DescribeResourceGroups(self, request):
-        """获取资源组列表
+        """因业务策略调整，腾讯云TI平台TI-EMS已经于2022年6月30日下线并停止提供服务。若您有新增的业务需求，可前往TI-ONE(https://cloud.tencent.com/document/product/851)使用。
+
+        获取资源组列表
 
         :param request: Request instance for DescribeResourceGroups.
         :type request: :class:`tencentcloud.tiems.v20190416.models.DescribeResourceGroupsRequest`
@@ -399,7 +441,8 @@ class TiemsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeResourceGroups", params)
+            headers = request.headers
+            body = self.call("DescribeResourceGroups", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeResourceGroupsResponse()
@@ -418,7 +461,9 @@ class TiemsClient(AbstractClient):
 
 
     def DescribeRsgAsGroupActivities(self, request):
-        """查询伸缩组活动
+        """因业务策略调整，腾讯云TI平台TI-EMS已经于2022年6月30日下线并停止提供服务。若您有新增的业务需求，可前往TI-ONE(https://cloud.tencent.com/document/product/851)使用。
+
+        查询伸缩组活动
 
         :param request: Request instance for DescribeRsgAsGroupActivities.
         :type request: :class:`tencentcloud.tiems.v20190416.models.DescribeRsgAsGroupActivitiesRequest`
@@ -427,7 +472,8 @@ class TiemsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeRsgAsGroupActivities", params)
+            headers = request.headers
+            body = self.call("DescribeRsgAsGroupActivities", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeRsgAsGroupActivitiesResponse()
@@ -446,7 +492,9 @@ class TiemsClient(AbstractClient):
 
 
     def DescribeRsgAsGroups(self, request):
-        """查询资源组的伸缩组信息
+        """因业务策略调整，腾讯云TI平台TI-EMS已经于2022年6月30日下线并停止提供服务。若您有新增的业务需求，可前往TI-ONE(https://cloud.tencent.com/document/product/851)使用。
+
+        查询资源组的伸缩组信息
 
         :param request: Request instance for DescribeRsgAsGroups.
         :type request: :class:`tencentcloud.tiems.v20190416.models.DescribeRsgAsGroupsRequest`
@@ -455,7 +503,8 @@ class TiemsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeRsgAsGroups", params)
+            headers = request.headers
+            body = self.call("DescribeRsgAsGroups", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeRsgAsGroupsResponse()
@@ -474,7 +523,9 @@ class TiemsClient(AbstractClient):
 
 
     def DescribeRuntimes(self, request):
-        """描述服务运行环境
+        """因业务策略调整，腾讯云TI平台TI-EMS已经于2022年6月30日下线并停止提供服务。若您有新增的业务需求，可前往TI-ONE(https://cloud.tencent.com/document/product/851)使用。
+
+        描述服务运行环境
 
         :param request: Request instance for DescribeRuntimes.
         :type request: :class:`tencentcloud.tiems.v20190416.models.DescribeRuntimesRequest`
@@ -483,7 +534,8 @@ class TiemsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeRuntimes", params)
+            headers = request.headers
+            body = self.call("DescribeRuntimes", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeRuntimesResponse()
@@ -502,7 +554,9 @@ class TiemsClient(AbstractClient):
 
 
     def DescribeServiceConfigs(self, request):
-        """描述服务配置
+        """因业务策略调整，腾讯云TI平台TI-EMS已经于2022年6月30日下线并停止提供服务。若您有新增的业务需求，可前往TI-ONE(https://cloud.tencent.com/document/product/851)使用。
+
+        描述服务配置
 
         :param request: Request instance for DescribeServiceConfigs.
         :type request: :class:`tencentcloud.tiems.v20190416.models.DescribeServiceConfigsRequest`
@@ -511,7 +565,8 @@ class TiemsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeServiceConfigs", params)
+            headers = request.headers
+            body = self.call("DescribeServiceConfigs", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeServiceConfigsResponse()
@@ -530,7 +585,9 @@ class TiemsClient(AbstractClient):
 
 
     def DescribeServices(self, request):
-        """描述服务
+        """因业务策略调整，腾讯云TI平台TI-EMS已经于2022年6月30日下线并停止提供服务。若您有新增的业务需求，可前往TI-ONE(https://cloud.tencent.com/document/product/851)使用。
+
+        描述服务
 
         :param request: Request instance for DescribeServices.
         :type request: :class:`tencentcloud.tiems.v20190416.models.DescribeServicesRequest`
@@ -539,7 +596,8 @@ class TiemsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeServices", params)
+            headers = request.headers
+            body = self.call("DescribeServices", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeServicesResponse()
@@ -558,7 +616,9 @@ class TiemsClient(AbstractClient):
 
 
     def DisableRsgAsGroup(self, request):
-        """停用资源组的伸缩组
+        """因业务策略调整，腾讯云TI平台TI-EMS已经于2022年6月30日下线并停止提供服务。若您有新增的业务需求，可前往TI-ONE(https://cloud.tencent.com/document/product/851)使用。
+
+        停用资源组的伸缩组
 
         :param request: Request instance for DisableRsgAsGroup.
         :type request: :class:`tencentcloud.tiems.v20190416.models.DisableRsgAsGroupRequest`
@@ -567,7 +627,8 @@ class TiemsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DisableRsgAsGroup", params)
+            headers = request.headers
+            body = self.call("DisableRsgAsGroup", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DisableRsgAsGroupResponse()
@@ -586,7 +647,9 @@ class TiemsClient(AbstractClient):
 
 
     def EnableRsgAsGroup(self, request):
-        """启用资源组的伸缩组
+        """因业务策略调整，腾讯云TI平台TI-EMS已经于2022年6月30日下线并停止提供服务。若您有新增的业务需求，可前往TI-ONE(https://cloud.tencent.com/document/product/851)使用。
+
+        启用资源组的伸缩组
 
         :param request: Request instance for EnableRsgAsGroup.
         :type request: :class:`tencentcloud.tiems.v20190416.models.EnableRsgAsGroupRequest`
@@ -595,7 +658,8 @@ class TiemsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("EnableRsgAsGroup", params)
+            headers = request.headers
+            body = self.call("EnableRsgAsGroup", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.EnableRsgAsGroupResponse()
@@ -614,7 +678,9 @@ class TiemsClient(AbstractClient):
 
 
     def ExposeService(self, request):
-        """暴露服务
+        """因业务策略调整，腾讯云TI平台TI-EMS已经于2022年6月30日下线并停止提供服务。若您有新增的业务需求，可前往TI-ONE(https://cloud.tencent.com/document/product/851)使用。
+
+        暴露服务
 
         :param request: Request instance for ExposeService.
         :type request: :class:`tencentcloud.tiems.v20190416.models.ExposeServiceRequest`
@@ -623,7 +689,8 @@ class TiemsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ExposeService", params)
+            headers = request.headers
+            body = self.call("ExposeService", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ExposeServiceResponse()
@@ -642,7 +709,9 @@ class TiemsClient(AbstractClient):
 
 
     def UpdateJob(self, request):
-        """更新任务
+        """因业务策略调整，腾讯云TI平台TI-EMS已经于2022年6月30日下线并停止提供服务。若您有新增的业务需求，可前往TI-ONE(https://cloud.tencent.com/document/product/851)使用。
+
+        更新任务
 
         :param request: Request instance for UpdateJob.
         :type request: :class:`tencentcloud.tiems.v20190416.models.UpdateJobRequest`
@@ -651,7 +720,8 @@ class TiemsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("UpdateJob", params)
+            headers = request.headers
+            body = self.call("UpdateJob", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.UpdateJobResponse()
@@ -670,7 +740,9 @@ class TiemsClient(AbstractClient):
 
 
     def UpdateRsgAsGroup(self, request):
-        """更新资源组的伸缩组
+        """因业务策略调整，腾讯云TI平台TI-EMS已经于2022年6月30日下线并停止提供服务。若您有新增的业务需求，可前往TI-ONE(https://cloud.tencent.com/document/product/851)使用。
+
+        更新资源组的伸缩组
 
         :param request: Request instance for UpdateRsgAsGroup.
         :type request: :class:`tencentcloud.tiems.v20190416.models.UpdateRsgAsGroupRequest`
@@ -679,7 +751,8 @@ class TiemsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("UpdateRsgAsGroup", params)
+            headers = request.headers
+            body = self.call("UpdateRsgAsGroup", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.UpdateRsgAsGroupResponse()
@@ -698,7 +771,9 @@ class TiemsClient(AbstractClient):
 
 
     def UpdateService(self, request):
-        """更新服务
+        """因业务策略调整，腾讯云TI平台TI-EMS已经于2022年6月30日下线并停止提供服务。若您有新增的业务需求，可前往TI-ONE(https://cloud.tencent.com/document/product/851)使用。
+
+        更新服务
 
         :param request: Request instance for UpdateService.
         :type request: :class:`tencentcloud.tiems.v20190416.models.UpdateServiceRequest`
@@ -707,7 +782,8 @@ class TiemsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("UpdateService", params)
+            headers = request.headers
+            body = self.call("UpdateService", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.UpdateServiceResponse()
